@@ -6,6 +6,9 @@ from devsecops_engine_tools.engine_core.src.domain.model.threshold import Thresh
 from devsecops_engine_tools.engine_core.src.domain.model.level_vulnerability import (
     LevelVulnerability,
 )
+from devsecops_engine_tools.engine_core.src.domain.model.level_compliance import (
+    LevelCompliance,
+)
 
 
 class Utils:
@@ -20,21 +23,23 @@ class Utils:
         return base64_token
 
     def update_threshold(self, threshold: Threshold, exclusions_data, pipeline_name):
-        def set_vulnerability(level):
-            threshold.vulnerability = LevelVulnerability(level)
+        def set_threshold(new_threshold):
+            threshold.vulnerability = LevelVulnerability(new_threshold.get("VULNERABILITY"))
+            threshold.compliance = LevelCompliance(new_threshold.get("COMPLIANCE")) if new_threshold.get("COMPLIANCE") else threshold.compliance
+            threshold.cve = new_threshold.get("CVE") if new_threshold.get("CVE") is not None else threshold.cve
             return threshold
 
         threshold_pipeline = exclusions_data.get(pipeline_name, {}).get("THRESHOLD", {})
         if threshold_pipeline:
-            return set_vulnerability(threshold_pipeline.get("VULNERABILITY"))
+            return set_threshold(threshold_pipeline)
 
         search_patterns = exclusions_data.get("BY_PATTERN_SEARCH", {})
         
         match_pattern = next(
-            (v["THRESHOLD"]["VULNERABILITY"]
+            (v["THRESHOLD"]
             for pattern, v in search_patterns.items()
             if re.match(pattern, pipeline_name, re.IGNORECASE)),
             None
         )
 
-        return set_vulnerability(match_pattern) if match_pattern else threshold
+        return set_threshold(match_pattern) if match_pattern else threshold
